IMTreatment package
===================

.. automodule:: IMTreatment
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    IMTreatment.boundary_layer
    IMTreatment.core
    IMTreatment.field_treatment
    IMTreatment.file_operation
    IMTreatment.plotlib
    IMTreatment.pod
    IMTreatment.potential_flow
    IMTreatment.protocols
    IMTreatment.stabilize
    IMTreatment.utils
    IMTreatment.vortex_creation
    IMTreatment.vortex_criterions
    IMTreatment.vortex_detection
    IMTreatment.vortex_properties

